@@ -1,4 +1,4 @@
-# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gnome2-Rsvg/Rsvg.pm,v 1.5 2005/02/24 17:54:31 kaffeetisch Exp $
+# $Header: /cvsroot/gtk2-perl/gtk2-perl-xs/Gnome2-Rsvg/Rsvg.pm,v 1.7 2005/09/17 19:48:11 kaffeetisch Exp $
 
 package Gnome2::Rsvg;
 
@@ -12,17 +12,14 @@ use Gtk2;
 require DynaLoader;
 
 our @ISA = qw(DynaLoader);
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 sub dl_load_flags { $^O eq 'darwin' ? 0x00 : 0x01 }
 
 Gnome2::Rsvg -> bootstrap($VERSION);
 
-# Preloaded methods go here.
-
 1;
 __END__
-# Below is stub documentation for your module. You'd better edit it!
 
 =head1 NAME
 
@@ -64,10 +61,10 @@ L<http://librsvg.sourceforge.net/docs/html/index.html>
 
 =head1 AUTHOR
 
-Torsten Schoenfeld E<lt>kaffeetisch@web.deE<gt>.
+Torsten Schoenfeld E<lt>kaffeetisch at gmx dot deE<gt>.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2003 by the gtk2-perl team
+Copyright (C) 2003-2005 by the gtk2-perl team
 
 =cut
